@@ -67,7 +67,7 @@ class Assistant(QWidget):
             ("Export Python script to file", self.to_python),
             ("Export Jupyter Notebook", self.to_notebook),
             ("Export Jupyter Notebook using Napari", self.to_notebook_using_napari),
-            ("Copy to clipboard", self.to_clipboard),
+            ("Copy Python code to clipboard", self.to_clipboard),
         ]
 
         # create workflow menu
@@ -82,6 +82,12 @@ class Assistant(QWidget):
             self.actions.append(("Send to Script Editor", self.to_script_editor))
         except ImportError:
             pass
+        # add plugin generator menu in case it's installed
+        try:
+            import napari_assistant_plugin_generator
+            self.actions.append(("Generate Napari plugin", self.to_napari_plugin))
+        except ImportError:
+            pass
 
         self.setLayout(QVBoxLayout())
         search_and_help = QWidget()
@@ -321,6 +327,9 @@ class Assistant(QWidget):
                     warn(f"Failed to execute notebook: {e}")
         return nb
 
+    def to_napari_plugin(self):
+        from napari_assistant_plugin_generator import make_plugin
+        self._viewer.window.add_dock_widget(make_plugin())
 
     def to_clipboard(self):
         import pyperclip
